@@ -1,4 +1,3 @@
-import re
 # what file extensions should we monitor
 source_ext = 'xjs'
 exts = ['js', source_ext]
@@ -6,6 +5,6 @@ exts = ['js', source_ext]
 sources = {}
 source_dir = None
 dest_dir = None
-import_regex = '(#!(?P<command>import|require)) (?P<script>\S+(.\S+)(.xjs|.js))'
+import_regex = '(//(\s*)(?P<command>import|require)) (\"|\')?(?P<script>\S+(.\S+)(.xjs|.js))(\"|\')?'
 file_regex = '([a-zA-Z/]*.(?!min)(xjs|js))'
 stack = []
